@@ -306,8 +306,15 @@ type zipAndUploader interface {
 	ZipAndUpload(bucket, key string, files ...s3.NamedBinary) (string, error)
 }
 
+type Uploader interface {
+	zipAndUploader
+	Upload(bucket, key string, file s3.NamedBinary) (string, error)
+}
+
 type customResourcesUploader interface {
 	UploadEnvironmentCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error)
+	UploadRequestDrivenWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error)
+	UploadRequestDrivenWebServiceLayers(upload s3.UploadFunc) (map[string]string, error)
 }
 
 type bucketEmptier interface {
@@ -408,6 +415,10 @@ type versionGetter interface {
 	Version() (string, error)
 }
 
+type endpointGetter interface {
+	ServiceDiscoveryEndpoint() (string, error)
+}
+
 type envTemplater interface {
 	EnvironmentTemplate(appName, envName string) (string, error)
 }
@@ -570,7 +581,7 @@ type runningTaskSelector interface {
 
 type dockerEngine interface {
 	CheckDockerEngineRunning() error
-	GetPlatform() (string, string, error)
+	RedirectPlatform(string) (*string, error)
 }
 
 type codestar interface {
