@@ -9,6 +9,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
+
 	"github.com/aws/aws-sdk-go/aws"
 	addon "github.com/aws/copilot-cli/internal/pkg/addon"
 	"github.com/aws/copilot-cli/internal/pkg/config"
@@ -202,6 +204,22 @@ func TestSvcDeployOpts_configureContainerImage(t *testing.T) {
 	mockError := errors.New("mockError")
 	mockManifest := []byte(`name: serviceA
 type: 'Load Balanced Web Service'
+image:
+  build:
+    dockerfile: path/to/Dockerfile
+    context: path
+`)
+	mockManifestWithBadPlatform := []byte(`name: serviceA
+type: 'Load Balanced Web Service'
+platform: linus/abc123
+image:
+  build:
+    dockerfile: path/to/Dockerfile
+    context: path
+`)
+	mockManifestWithGoodPlatform := []byte(`name: serviceA
+type: 'Load Balanced Web Service'
+platform: linux/amd64
 image:
   build:
     dockerfile: path/to/Dockerfile
@@ -249,6 +267,31 @@ image:
 			},
 			wantErr: fmt.Errorf("get copilot directory: %w", mockError),
 		},
+		"should return error if platform is invalid": {
+			inputSvc: "serviceA",
+			setupMocks: func(m deploySvcMocks) {
+				gomock.InOrder(
+					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifestWithBadPlatform, nil),
+					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+				)
+			},
+			wantErr: fmt.Errorf("get platform for service: validate platform: platform %s is invalid; the valid platform is: %s", "linus/abc123", "linux/amd64"),
+		},
+		"success with valid platform": {
+			inputSvc: "serviceA",
+			setupMocks: func(m deploySvcMocks) {
+				gomock.InOrder(
+					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifestWithGoodPlatform, nil),
+					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
+					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &exec.BuildArguments{
+						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
+						Context:    filepath.Join("/ws", "root", "path"),
+						Platform:   "linux/amd64",
+					}).Return("sha256:741d3e95eefa2c3b594f970a938ed6e497b50b3541a5fdc28af3ad8959e76b49", nil),
+				)
+			},
+			wantedDigest: "sha256:741d3e95eefa2c3b594f970a938ed6e497b50b3541a5fdc28af3ad8959e76b49",
+		},
 		"success without building and pushing": {
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
@@ -406,7 +449,7 @@ func TestSvcDeployOpts_pushAddonsTemplateToS3Bucket(t *testing.T) {
 			},
 			mockS3Svc: func(m *mocks.MockartifactUploader) {},
 
-			wantErr: fmt.Errorf("get app resources: some error"),
+			wantErr: fmt.Errorf("get application mockApp resources from region us-west-2: some error"),
 		},
 		"should return error if fail to upload to S3 bucket": {
 			inputSvc: "mockSvc",
@@ -517,6 +560,8 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 		mockWorkspace          func(m *mocks.MockwsSvcDirReader)
 		mockAppResourcesGetter func(m *mocks.MockappResourcesGetter)
 		mockAppVersionGetter   func(m *mocks.MockversionGetter)
+		mockEndpointGetter     func(m *mocks.MockendpointGetter)
+		mockIdentity           func(m *mocks.MockidentityService)
 
 		wantErr error
 	}{
@@ -526,6 +571,7 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			},
 			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {},
 			mockAppVersionGetter:   func(m *mocks.MockversionGetter) {},
+			mockEndpointGetter:     func(m *mocks.MockendpointGetter) {},
 			wantErr:                fmt.Errorf("read service %s manifest file: %w", mockSvcName, mockError),
 		},
 		"fail to get app resources": {
@@ -545,6 +591,9 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 					Name: mockAppName,
 				}, "us-west-2").Return(nil, mockError)
 			},
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {},
 			wantErr:              fmt.Errorf("get application %s resources from region us-west-2: %w", mockAppName, mockError),
 		},
@@ -569,6 +618,9 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 					RepositoryURLs: map[string]string{},
 				}, nil)
 			},
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {},
 			wantErr:              fmt.Errorf("ECR repository not found for service mockSvc in region us-west-2 and account 1234567890"),
 		},
@@ -589,6 +641,9 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {
 				m.EXPECT().Version().Return("", mockError)
 			},
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
 			wantErr: fmt.Errorf("get version for app %s: %w", mockAppName, mockError),
 		},
 		"fail to enable https alias because of incompatible app version": {
@@ -608,6 +663,9 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {
 				m.EXPECT().Version().Return("v0.0.0", nil)
 			},
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
 			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
 		},
 		"fail to enable https alias because of invalid alias": {
@@ -627,7 +685,10 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {
 				m.EXPECT().Version().Return("v1.0.0", nil)
 			},
-			wantErr: fmt.Errorf("alias is not supported in hosted zones not managed by Copilot"),
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
+			wantErr: fmt.Errorf("alias is not supported in hosted zones that are not managed by Copilot"),
 		},
 		"success": {
 			inAlias: "v1.mockDomain",
@@ -646,6 +707,9 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			mockAppVersionGetter: func(m *mocks.MockversionGetter) {
 				m.EXPECT().Version().Return("v1.0.0", nil)
 			},
+			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
+				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
 		},
 	}
 
@@ -657,9 +721,11 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 			mockWorkspace := mocks.NewMockwsSvcDirReader(ctrl)
 			mockAppResourcesGetter := mocks.NewMockappResourcesGetter(ctrl)
 			mockAppVersionGetter := mocks.NewMockversionGetter(ctrl)
+			mockEndpointGetter := mocks.NewMockendpointGetter(ctrl)
 			tc.mockWorkspace(mockWorkspace)
 			tc.mockAppResourcesGetter(mockAppResourcesGetter)
 			tc.mockAppVersionGetter(mockAppVersionGetter)
+			tc.mockEndpointGetter(mockEndpointGetter)
 
 			opts := deploySvcOpts{
 				deployWkldVars: deployWkldVars{
@@ -673,6 +739,7 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 				newAppVersionGetter: func(s string) (versionGetter, error) {
 					return mockAppVersionGetter, nil
 				},
+				endpointGetter:    mockEndpointGetter,
 				targetApp:         tc.inApp,
 				targetEnvironment: tc.inEnvironment,
 				unmarshal: func(b []byte) (manifest.WorkloadManifest, error) {
@@ -699,3 +766,281 @@ func TestSvcDeployOpts_stackConfiguration(t *testing.T) {
 		})
 	}
 }
+
+type deployRDSvcMocks struct {
+	mockWorkspace          *mocks.MockwsSvcDirReader
+	mockAppResourcesGetter *mocks.MockappResourcesGetter
+	mockAppVersionGetter   *mocks.MockversionGetter
+	mockEndpointGetter     *mocks.MockendpointGetter
+	mockIdentity           *mocks.MockidentityService
+	mockUploader           *mocks.MockcustomResourcesUploader
+}
+
+func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
+	const (
+		mockAppName   = "mockApp"
+		mockEnvName   = "mockEnv"
+		mockSvcName   = "mockSvc"
+		mockAddonsURL = "mockAddonsURL"
+	)
+	tests := map[string]struct {
+		inAlias        string
+		inApp          *config.Application
+		inEnvironment  *config.Environment
+		inBuildRequire bool
+
+		mock func(m *deployRDSvcMocks)
+
+		wantURLs map[string]string
+		wantErr  error
+	}{
+		"fail to get identity for rd web service": {
+			inAlias: "v1.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{}, errors.New("some error"))
+			},
+
+			wantErr: fmt.Errorf("get identity: some error"),
+		},
+		"errors getting app resources by region": {
+			inAlias: "v1.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name:   mockAppName,
+					Domain: "mockDomain",
+				}, "us-west-2").Return(nil, errors.New("some error"))
+			},
+
+			wantErr: fmt.Errorf("get application mockApp resources from region us-west-2: some error"),
+		},
+		"invalid alias with unknown domain": {
+			inAlias: "v1.someRandomDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+			},
+
+			wantErr: fmt.Errorf("alias is not supported in hosted zones that are not managed by Copilot"),
+		},
+		"invalid environment level alias": {
+			inAlias: "mockEnv.mockApp.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+			},
+
+			wantErr: fmt.Errorf("mockEnv.mockApp.mockDomain is an environment-level alias, which is not supported yet"),
+		},
+		"invalid application level alias": {
+			inAlias: "someSub.mockApp.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+			},
+
+			wantErr: fmt.Errorf("someSub.mockApp.mockDomain is an application-level alias, which is not supported yet"),
+		},
+		"invalid root level alias": {
+			inAlias: "mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+			},
+
+			wantErr: fmt.Errorf("mockDomain is a root domain alias, which is not supported yet"),
+		},
+		"fail to upload custom resource scripts": {
+			inAlias: "v1.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name:   mockAppName,
+					Domain: "mockDomain",
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockUploader.EXPECT().UploadRequestDrivenWebServiceCustomResources(gomock.Any()).Return(nil, errors.New("some error"))
+			},
+
+			wantErr: fmt.Errorf("upload custom resources to bucket mockBucket: some error"),
+		},
+		"success": {
+			inAlias: "v1.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
+					RootUserARN: "1234",
+				}, nil)
+				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
+					Name:   mockAppName,
+					Domain: "mockDomain",
+				}, "us-west-2").Return(&stack.AppRegionalResources{
+					S3Bucket: "mockBucket",
+				}, nil)
+				m.mockUploader.EXPECT().UploadRequestDrivenWebServiceCustomResources(gomock.Any()).Return(map[string]string{
+					"mockResource2": "mockURL2",
+				}, nil)
+			},
+			wantURLs: map[string]string{
+				"mockResource1": "mockURL1",
+				"mockResource2": "mockURL2",
+			},
+		},
+	}
+
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := &deployRDSvcMocks{
+				mockWorkspace:          mocks.NewMockwsSvcDirReader(ctrl),
+				mockAppResourcesGetter: mocks.NewMockappResourcesGetter(ctrl),
+				mockAppVersionGetter:   mocks.NewMockversionGetter(ctrl),
+				mockEndpointGetter:     mocks.NewMockendpointGetter(ctrl),
+				mockIdentity:           mocks.NewMockidentityService(ctrl),
+				mockUploader:           mocks.NewMockcustomResourcesUploader(ctrl),
+			}
+			tc.mock(m)
+
+			opts := deploySvcOpts{
+				deployWkldVars: deployWkldVars{
+					name:    mockSvcName,
+					appName: mockAppName,
+					envName: mockEnvName,
+				},
+				ws:     m.mockWorkspace,
+				appCFN: m.mockAppResourcesGetter,
+				newAppVersionGetter: func(s string) (versionGetter, error) {
+					return m.mockAppVersionGetter, nil
+				},
+				endpointGetter:    m.mockEndpointGetter,
+				identity:          m.mockIdentity,
+				targetApp:         tc.inApp,
+				targetEnvironment: tc.inEnvironment,
+				unmarshal: func(b []byte) (manifest.WorkloadManifest, error) {
+					return &manifest.RequestDrivenWebService{
+						Workload: manifest.Workload{
+							Name: aws.String(mockSvcName),
+						},
+						RequestDrivenWebServiceConfig: manifest.RequestDrivenWebServiceConfig{
+							RequestDrivenWebServiceHttpConfig: manifest.RequestDrivenWebServiceHttpConfig{
+								Alias: aws.String(tc.inAlias),
+							},
+						},
+					}, nil
+				},
+				uploadOpts: &uploadCustomResourcesOpts{
+					uploader: m.mockUploader,
+					newS3Uploader: func() (Uploader, error) {
+						return nil, nil
+					},
+				},
+			}
+
+			_, gotErr := opts.stackConfiguration(mockAddonsURL)
+
+			if tc.wantErr != nil {
+				require.EqualError(t, gotErr, tc.wantErr.Error())
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+
+}
