@@ -66,7 +66,7 @@ type WorkloadProps struct {
 	Name           string
 	DockerfilePath string
 	Image          string
-	Platform       *manifest.PlatformConfig
+	Platform       *string
 }
 
 // JobProps contains the information needed to represent a Job.
