@@ -72,6 +72,7 @@ type Workload struct {
 type Image struct {
 	Build        BuildArgsOrString `yaml:"build"`           // Build an image from a Dockerfile.
 	Location     *string           `yaml:"location"`        // Use an existing image instead.
+	Credentials  *string           `yaml:"credentials"`     // ARN of the secret containing the private repository credentials.
 	DockerLabels map[string]string `yaml:"labels,flow"`     // Apply Docker labels to the container at runtime.
 	DependsOn    map[string]string `yaml:"depends_on,flow"` // Add any sidecar dependencies.
 }
@@ -428,21 +429,23 @@ func (lc *Logging) GetEnableMetadata() *string {
 
 // SidecarConfig represents the configurable options for setting up a sidecar container.
 type SidecarConfig struct {
-	Port         *string             `yaml:"port"`
-	Image        *string             `yaml:"image"`
-	Essential    *bool               `yaml:"essential"`
-	CredsParam   *string             `yaml:"credentialsParameter"`
-	Variables    map[string]string   `yaml:"variables"`
-	Secrets      map[string]string   `yaml:"secrets"`
-	MountPoints  []SidecarMountPoint `yaml:"mount_points"`
-	DockerLabels map[string]string   `yaml:"labels"`
-	DependsOn    map[string]string   `yaml:"depends_on"`
+	Port          *string             `yaml:"port"`
+	Image         *string             `yaml:"image"`
+	Essential     *bool               `yaml:"essential"`
+	CredsParam    *string             `yaml:"credentialsParameter"`
+	Variables     map[string]string   `yaml:"variables"`
+	Secrets       map[string]string   `yaml:"secrets"`
+	MountPoints   []SidecarMountPoint `yaml:"mount_points"`
+	DockerLabels  map[string]string   `yaml:"labels"`
+	DependsOn     map[string]string   `yaml:"depends_on"`
+	ImageOverride `yaml:",inline"`
 }
 
 // TaskConfig represents the resource boundaries and environment variables for the containers in the task.
 type TaskConfig struct {
 	CPU            *int              `yaml:"cpu"`
 	Memory         *int              `yaml:"memory"`
+	Platform       *string           `yaml:"platform,omitempty"`
 	Count          Count             `yaml:"count"`
 	ExecuteCommand ExecuteCommand    `yaml:"exec"`
 	Variables      map[string]string `yaml:"variables"`
@@ -466,12 +469,6 @@ type NetworkConfig struct {
 	VPC *vpcConfig `yaml:"vpc"`
 }
 
-// PlatformConfig represents operating system and architecture specifications.
-type PlatformConfig struct {
-	OS   string `yaml:"os"`
-	Arch string `yaml:"architecture"`
-}
-
 // UnmarshalYAML ensures that a NetworkConfig always defaults to public subnets.
 // If the user specified a placement that's not valid then throw an error.
 func (c *NetworkConfig) UnmarshalYAML(unmarshal func(interface{}) error) error {
@@ -542,6 +539,12 @@ func UnmarshalWorkload(in []byte) (WorkloadManifest, error) {
 			return nil, fmt.Errorf("unmarshal to backend service: %w", err)
 		}
 		return m, nil
+	case WorkerServiceType:
+		m := newDefaultWorkerService()
+		if err := yaml.Unmarshal(in, m); err != nil {
+			return nil, fmt.Errorf("unmarshal to worker service: %w", err)
+		}
+		return m, nil
 	case ScheduledJobType:
 		m := newDefaultScheduledJob()
 		if err := yaml.Unmarshal(in, m); err != nil {
