@@ -119,33 +119,34 @@ func generateMountPointJSON(mountPoints []*MountPoint) string {
 		}
 		volumeMap[aws.StringValue(mp.SourceVolume)] = aws.StringValue(mp.ContainerPath)
 	}
-	// Check for empty maps
-	if len(volumeMap) == 0 {
+
+	out, ok := getJSONMap(volumeMap)
+	if !ok {
 		return "{}"
 	}
 
-	out, err := json.Marshal(volumeMap)
-	if err != nil {
-		return "{}"
-	}
 	return string(out)
 
 }
 
 // generatePublisherJSON turns a list of Topics objects into a JSON string:
-// `{"myTopic": ["hello"], "mySecondTopic": ["hello","goodbye"]}`
+// `{"myTopic": "topicArn", "mySecondTopic": "secondTopicArn"}`
 // This function must be called on an array of correctly constructed Topic objects.
-func generatePublishJSON(topics []*Topics) string {
-	publisherMap := make(map[string][]string)
+func generateSNSJSON(topics []*Topic) string {
+	if topics == nil {
+		return ""
+	}
+	topicMap := make(map[string]string)
 
-	for _, pb := range topics {
-		if aws.StringValue(pb.Name) == "" {
+	for _, topic := range topics {
+		// Topics with no name will not be included in the json
+		if topic.Name == nil {
 			continue
 		}
-		publisherMap[aws.StringValue(pb.Name)] = aws.StringValueSlice(pb.AllowedWorkers)
+		topicMap[aws.StringValue(topic.Name)] = topic.ARN()
 	}
 
-	out, ok := getJSONMap(publisherMap)
+	out, ok := getJSONMap(topicMap)
 	if !ok {
 		return "{}"
 	}
@@ -153,7 +154,37 @@ func generatePublishJSON(topics []*Topics) string {
 	return string(out)
 }
 
-func getJSONMap(inMap map[string][]string) ([]byte, bool) {
+// generateQueueURIJSON turns a list of Topic Subscription objects into a JSON string of their corresponding queues:
+// `{"eventsQueue": "${mainURL}", "svcTopicEventsQueue": "${svctopicURL}"}`
+// This function must be called on an array of correctly constructed Topic objects.
+func generateQueueURIJSON(ts []*TopicSubscription) string {
+	if ts == nil {
+		return ""
+	}
+	urlMap := make(map[string]string)
+	urlMap["eventsQueue"] = "${mainURL}"
+
+	for _, sub := range ts {
+		// TopicSubscriptions with no name, service, or queue will not be included in the json
+		if sub.Name == nil || sub.Service == nil || sub.Queue == nil {
+			continue
+		}
+		svc := StripNonAlphaNumFunc(aws.StringValue(sub.Service))
+		topicName := StripNonAlphaNumFunc(aws.StringValue(sub.Name))
+		subName := fmt.Sprintf("%s%sEventsQueue", svc, strings.Title(topicName))
+
+		urlMap[subName] = fmt.Sprintf("${%s%sURL}", svc, topicName)
+	}
+
+	out, ok := getJSONMap(urlMap)
+	if !ok {
+		return "{}"
+	}
+
+	return string(out)
+}
+
+func getJSONMap(inMap map[string]string) ([]byte, bool) {
 	// Check for empty maps
 	if len(inMap) == 0 {
 		return nil, false
